@@ -1,6 +1,7 @@
 from qaseio.api_client import ApiClient
 from qaseio.configuration import Configuration
 from qaseio.api.attachments_api import AttachmentsApi
+from qaseio.api.environments_api import EnvironmentsApi
 from qaseio.api.projects_api import ProjectsApi
 from qaseio.api.results_api import ResultsApi
 from qaseio.api.runs_api import RunsApi
@@ -15,15 +16,6 @@ from datetime import datetime
 import more_itertools
 import certifi
 
-from pkg_resources import DistributionNotFound, get_distribution
-
-def package_version(name):
-    try:
-        version = get_distribution(name).version
-    except DistributionNotFound:
-        version = "unknown"
-    return version
-
 class TestOpsRunNotFoundException(Exception):
     pass
 
@@ -58,14 +50,14 @@ class QaseTestOps:
         self.defect = parseBool(defect)
         self.complete_after_run = parseBool(complete_run)
         self.environment = None
-        if environment:
-            if isinstance(environment, str):
-                self.environment = self._get_environment(environment)
-            elif isinstance(environment, int):
-                self.environment_id = environment
         self.host = host
         self.enabled = True
         self.chunk_size = min(2000, max(10, int(chunk_size)))
+        if environment:
+            if isinstance(environment, int) or (isinstance(environment, str) and environment.isnumeric()):
+                self.environment = environment
+            elif isinstance(environment, str):
+                self.environment = self._get_environment(environment, self.project_code)
 
         if run_title and run_title != '':
             self.run_title = run_title
@@ -93,8 +85,14 @@ class QaseTestOps:
                 print("[Qase] ⚠️  Disabling Qase TestOps reporter. Exception when calling ProjectApi->get_project: %s\n" % e)
 
     # Method loads environment by name and returns environment id
-    def _get_environment(self, environment: str):
-        # TODO: Add support for environment lookup by name
+    def _get_environment(self, environment: str, project: str):
+        if self.enabled:
+            api_instance = EnvironmentsApi(self.client)
+            response = api_instance.get_environments(code=project)
+            if hasattr(response, 'result'):
+                for env in response.result.entities:
+                    if env["slug"] == environment:
+                        return env["id"]
         return None
 
     def _send_bulk_results(self):
@@ -160,7 +158,7 @@ class QaseTestOps:
                     api_results.create_result_bulk(
                         code=self.project_code,
                         id=self.run_id,
-                        result_create_bulk=ResultcreateBulk(
+                        resultcreate_bulk=ResultcreateBulk(
                             results=chunk
                         )
                     )
